Index: src/wp-includes/class-wp-taxonomy.php
===================================================================
--- src/wp-includes/class-wp-taxonomy.php	(revision 39263)
+++ src/wp-includes/class-wp-taxonomy.php	(working copy)
@@ -12,7 +12,7 @@
  *
  * @since 4.7.0
  */
-final class WP_Taxonomy {
+final class WP_Taxonomy implements ArrayAccess {
 	/**
 	 * Taxonomy key.
 	 *
@@ -413,4 +413,57 @@
 	public function remove_hooks() {
 		remove_filter( 'wp_ajax_add-' . $this->name, '_wp_ajax_add_hierarchical_term' );
 	}
+
+	/**
+	 * Method to implement ArrayAccess
+	 *
+	 * @since 4.7.0
+	 * @access public
+	 *
+	 * @param string $offset
+	 * @param mixed $value
+	 */
+	public function offsetSet( $offset, $value ) {
+		if ( ! empty( $offset ) ) {
+			$this->$offset = $value;
+		}
+	}
+
+	/**
+	 * Method to implement ArrayAccess
+	 *
+	 * @since 4.7.0
+	 * @access public
+	 *
+	 * @param string $offset
+	 * @return bool
+	 */
+	public function offsetExists( $offset ) {
+		return isset( $this->$offset );
+	}
+
+	/**
+	 * Method to implement ArrayAccess
+	 *
+	 * @since 4.7.0
+	 * @access public
+	 *
+	 * @param mixed $offset
+	 */
+	public function offsetUnset( $offset ) {
+		unset( $this->$offset );
+	}
+
+	/**
+	 * Method to implement ArrayAccess
+	 *
+	 * @since 4.7.0
+	 * @access public
+	 *
+	 * @param mixed $offset
+	 * @return mixed|null
+	 */
+	public function offsetGet( $offset ) {
+		return isset( $this->$offset ) ? $this->$offset : null;
+	}
 }
Index: src/wp-includes/taxonomy.php
===================================================================
--- src/wp-includes/taxonomy.php	(revision 39263)
+++ src/wp-includes/taxonomy.php	(working copy)
@@ -388,12 +388,13 @@
 	 * Fires after a taxonomy is registered.
 	 *
 	 * @since 3.3.0
+	 * @since 4.7.0 Converted the `$taxonomy_object` parameter to accept a WP_Taxonomy object.
 	 *
 	 * @param string       $taxonomy    Taxonomy slug.
 	 * @param array|string $object_type Object type or array of object types.
 	 * @param array        $args        Array of taxonomy registration arguments.
 	 */
-	do_action( 'registered_taxonomy', $taxonomy, $object_type, $args );
+	do_action( 'registered_taxonomy', $taxonomy, $object_type, $taxonomy_object );
 }
 
 /**
@@ -388,12 +388,13 @@
 	 *
-	 * @param string       $taxonomy    Taxonomy slug.
-	 * @param array|string $object_type Object type or array of object types.
-	 * @param array        $args        Array of taxonomy registration arguments.
+	 * @param string       $taxonomy        Taxonomy slug.
+	 * @param array|string $object_type     Object type or array of object types.
+	 * @param WP_Taxonomy  $taxonomy_object Taxonomy Object.
 	 */
